@@ -1,7 +1,7 @@
 #! /bin/bash
 _ARCH="aarch64"
-source /usr/lib/archboot/functions
-source /usr/lib/archboot/server_functions
+. /usr/lib/archboot/common.sh
+. /usr/lib/archboot/server.sh
 _root_check
 _update_aarch64_pacman_chroot || exit 1
 _update_source
